#!/bin/bash
set -e

source config

if [[ -d ${LOG_DIR} ]]; then
  rm -rf ${LOG_DIR}/*
else
  mkdir -p ${LOG_DIR}
fi

LOG=${LOG_DIR}/init.log
> $LOG # clear the log

log info "Init database ..." | tee -a $LOG 2>&1
if ! beeline -u jdbc:hive2://localhost:${PORT} -f ./sqls/init_db.sql --hivevar DB=${DB}>>$LOG 2>&1; then echo "Init database failed. We will try later..." ; fi | log info

log info "Cleaning up ..." | tee -a $LOG 2>&1
if [[ -d ${BUILD_DIR} ]]; then
  rm -rf ${BUILD_DIR}/*
else
  mkdir -p ${BUILD_DIR}
fi

# clean up HDFS Trash
hadoop fs -rm -r -f -skipTrash /user/*/.Trash/* >> $LOG 2>&1

log info "Prepare the query template ..." | tee -a $LOG 2>&1
for ii in `seq 1 4`; do
  cp -r mtsqls ${BUILD_DIR}/mtsqls_$ii
done

log info "Restore failed disk if necessary ..." | tee -a $LOG 2>&1
disk_host="emr-worker-3"
if [ $STORE = 'hdfs' ]; then
  dir=hdfs
else
  dir=jboot
fi
ssh $disk_host "if [ -d /mnt/disk1/${dir}.bk ]; then sudo mv /mnt/disk1/${dir}.bk /mnt/disk1/${dir}; sudo kill \`sudo jps |grep DataNode | awk '{print \$1}'\`; fi"
# Restore failed Raid disk
if sudo mdadm -D /dev/md0 | grep removed >/dev/null 2>&1 ; then sudo mdadm --manage /dev/md0 --add /dev/vdd >> $LOG 2>&1; fi

log info "Initialization finished." | tee -a $LOG 2>&1
