#!/bin/bash
set -e 

source config

LOG=${LOG_DIR}/load.log
> $LOG # clear the log

start=$(($(date +%s%N)/1000000))
log info "Load data started." | tee -a $LOG 2>&1

SOURCE=tpcds_${STORE}_text_${SF}

log info "Init the db ..." | tee -a $LOG 2>&1
beeline -u jdbc:hive2://localhost:${PORT} -f ./sqls/init_db.sql --hivevar DB=${DB} >> $LOG 2>&1

log info "Map data to text tables ..." | tee -a $LOG 2>&1
beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_text_tables.sql --hivevar DB=${SOURCE} --hivevar LOCATION=${HDFS_DIR}/${SF} >> $LOG 2>&1

log info "Load data to parquet tables and analyze tables ..." | tee -a $LOG 2>&1
{
  # Each SQL script include analyze commands after DDL and DML to get statistics
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_store_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_catalog_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_web_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_store_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_catalog_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_web_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_inventory.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  sleep 5
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/create_dim_tables.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
} >> $LOG 2>&1

wait

log info "Load data to tables finished." | tee -a $LOG 2>&1

log info "Map refresh data to text tables ..." | tee -a $LOG 2>&1
for ii in `seq 1 4`; do
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${BUILD_DIR}/mtsqls_$ii/create_mt_tables.sql --hivevar DB=${DB} --hivevar ROUND=$ii --hivevar LOCATION=${HDFS_DIR}/${SF}/mt_$ii >> $LOG 2>&1 &
done

wait

log info "Analyze tables start..." | tee -a $LOG 2>&1
{
  # Each SQL script include analyze commands after DDL and DML to get statistics
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_store_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_catalog_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_web_sales.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_store_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_catalog_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_web_returns.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
  beeline -u jdbc:hive2://localhost:${PORT}/${DB} -f ./sqls/analyze_inventory.sql --hivevar DB=${DB} --hivevar SOURCE=${SOURCE} --hivevar WAREHOUSE_DIR=${WAREHOUSE_DIR} &
} >> $LOG 2>&1
log info "Analyze tables finished..." | tee -a $LOG 2>&1

wait

end=$(($(date +%s%N)/1000000))
duration=$(( (end - start) / 1000))
sec=`bc <<< "scale=3; ($end - $start)/1000"`
elapse_time=`printf "%d:%02d:%02d, %s seconds" $(($duration / 3600)) $((($duration / 60) % 60)) $(($duration % 60)) $sec`
log info "Load data finished. Time token: $elapse_time" | tee -a $LOG 2>&1

#clean cache
pdsh -w emr-worker-[1-$wn] "sudo su - root -c 'echo 3 > /proc/sys/vm/drop_caches'"
thisdate=`date +%m-%d-%H:%M:%S.%2N`
log info "Clean caches at: ${thisdate}" | tee -a $LOG 2>&1
