set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: catalog_returns                                      
-- ============================================================
drop table if exists catalog_returns;
create table catalog_returns
(
    cr_returned_date_sk       bigint,
    cr_returned_time_sk       bigint,
    cr_item_sk                bigint      not null,
    cr_refunded_customer_sk   bigint,
    cr_refunded_cdemo_sk      bigint,
    cr_refunded_hdemo_sk      bigint,
    cr_refunded_addr_sk       bigint,
    cr_returning_customer_sk  bigint,
    cr_returning_cdemo_sk     bigint,
    cr_returning_hdemo_sk     bigint,
    cr_returning_addr_sk      bigint,
    cr_call_center_sk         bigint,
    cr_catalog_page_sk        bigint,
    cr_ship_mode_sk           bigint,
    cr_warehouse_sk           bigint,
    cr_reason_sk              bigint,
    cr_order_number           bigint      not null,
    cr_return_quantity        int,
    cr_return_amount          decimal(7,2),
    cr_return_tax             decimal(7,2),
    cr_return_amt_inc_tax     decimal(7,2),
    cr_fee                    decimal(7,2),
    cr_return_ship_cost       decimal(7,2),
    cr_refunded_cash          decimal(7,2),
    cr_reversed_charge        decimal(7,2),
    cr_store_credit           decimal(7,2),
    cr_net_loss               decimal(7,2)
)
using parquet
partitioned by (cr_returned_date_sk)
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true");

insert overwrite table catalog_returns partition(cr_returned_date_sk)
select
  tmp.cr_returned_time_sk,
  tmp.cr_item_sk,
  tmp.cr_refunded_customer_sk,
  tmp.cr_refunded_cdemo_sk,
  tmp.cr_refunded_hdemo_sk,
  tmp.cr_refunded_addr_sk,
  tmp.cr_returning_customer_sk,
  tmp.cr_returning_cdemo_sk,
  tmp.cr_returning_hdemo_sk,
  tmp.cr_returning_addr_sk,
  tmp.cr_call_center_sk,
  tmp.cr_catalog_page_sk,
  tmp.cr_ship_mode_sk,
  tmp.cr_warehouse_sk,
  tmp.cr_reason_sk,
  tmp.cr_order_number,
  tmp.cr_return_quantity,
  tmp.cr_return_amount,
  tmp.cr_return_tax,
  tmp.cr_return_amt_inc_tax,
  tmp.cr_fee,
  tmp.cr_return_ship_cost,
  tmp.cr_refunded_cash,
  tmp.cr_reversed_charge,
  tmp.cr_store_credit,
  tmp.cr_net_loss,
  tmp.cr_returned_date_sk
from(
  select
    cr.cr_returned_time_sk,
    cr.cr_item_sk,
    cr.cr_refunded_customer_sk,
    cr.cr_refunded_cdemo_sk,
    cr.cr_refunded_hdemo_sk,
    cr.cr_refunded_addr_sk,
    cr.cr_returning_customer_sk,
    cr.cr_returning_cdemo_sk,
    cr.cr_returning_hdemo_sk,
    cr.cr_returning_addr_sk,
    cr.cr_call_center_sk,
    cr.cr_catalog_page_sk,
    cr.cr_ship_mode_sk,
    cr.cr_warehouse_sk,
    cr.cr_reason_sk,
    cr.cr_order_number,
    cr.cr_return_quantity,
    cr.cr_return_amount,
    cr.cr_return_tax,
    cr.cr_return_amt_inc_tax,
    cr.cr_fee,
    cr.cr_return_ship_cost,
    cr.cr_refunded_cash,
    cr.cr_reversed_charge,
    cr.cr_store_credit,
    cr.cr_net_loss,
    cr.cr_returned_date_sk,
    case when cr.cr_returned_date_sk is not null then cr.cr_returned_date_sk else cast(rand() * 500 as int) end as distribute_key
  from ${SOURCE}.catalog_returns cr
  distribute by distribute_key
) tmp
;
