set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: catalog_sales                                      
-- ============================================================
drop table if exists catalog_sales;
create table catalog_sales
(
    cs_sold_date_sk           bigint,
    cs_sold_time_sk           bigint,
    cs_ship_date_sk           bigint,
    cs_bill_customer_sk       bigint,
    cs_bill_cdemo_sk          bigint,
    cs_bill_hdemo_sk          bigint,
    cs_bill_addr_sk           bigint,
    cs_ship_customer_sk       bigint,
    cs_ship_cdemo_sk          bigint,
    cs_ship_hdemo_sk          bigint,
    cs_ship_addr_sk           bigint,
    cs_call_center_sk         bigint,
    cs_catalog_page_sk        bigint,
    cs_ship_mode_sk           bigint,
    cs_warehouse_sk           bigint,
    cs_item_sk                bigint            not null,
    cs_promo_sk               bigint,
    cs_order_number           bigint            not null,
    cs_quantity               int,
    cs_wholesale_cost         decimal(7,2),
    cs_list_price             decimal(7,2),
    cs_sales_price            decimal(7,2),
    cs_ext_discount_amt       decimal(7,2),
    cs_ext_sales_price        decimal(7,2),
    cs_ext_wholesale_cost     decimal(7,2),
    cs_ext_list_price         decimal(7,2),
    cs_ext_tax                decimal(7,2),
    cs_coupon_amt             decimal(7,2),
    cs_ext_ship_cost          decimal(7,2),
    cs_net_paid               decimal(7,2),
    cs_net_paid_inc_tax       decimal(7,2),
    cs_net_paid_inc_ship      decimal(7,2),
    cs_net_paid_inc_ship_tax  decimal(7,2),
    cs_net_profit             decimal(7,2)
)
using parquet
partitioned by (cs_sold_date_sk)
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true");

insert overwrite table catalog_sales partition (cs_sold_date_sk)
select
  tmp.cs_sold_time_sk,
  tmp.cs_ship_date_sk,
  tmp.cs_bill_customer_sk,
  tmp.cs_bill_cdemo_sk,
  tmp.cs_bill_hdemo_sk,
  tmp.cs_bill_addr_sk,
  tmp.cs_ship_customer_sk,
  tmp.cs_ship_cdemo_sk,
  tmp.cs_ship_hdemo_sk,
  tmp.cs_ship_addr_sk,
  tmp.cs_call_center_sk,
  tmp.cs_catalog_page_sk,
  tmp.cs_ship_mode_sk,
  tmp.cs_warehouse_sk,
  tmp.cs_item_sk,
  tmp.cs_promo_sk,
  tmp.cs_order_number,
  tmp.cs_quantity,
  tmp.cs_wholesale_cost,
  tmp.cs_list_price,
  tmp.cs_sales_price,
  tmp.cs_ext_discount_amt,
  tmp.cs_ext_sales_price,
  tmp.cs_ext_wholesale_cost,
  tmp.cs_ext_list_price,
  tmp.cs_ext_tax,
  tmp.cs_coupon_amt,
  tmp.cs_ext_ship_cost,
  tmp.cs_net_paid,
  tmp.cs_net_paid_inc_tax,
  tmp.cs_net_paid_inc_ship,
  tmp.cs_net_paid_inc_ship_tax,
  tmp.cs_net_profit,
  tmp.cs_sold_date_sk
from(
  select
    cs.cs_sold_time_sk,
    cs.cs_ship_date_sk,
    cs.cs_bill_customer_sk,
    cs.cs_bill_cdemo_sk,
    cs.cs_bill_hdemo_sk,
    cs.cs_bill_addr_sk,
    cs.cs_ship_customer_sk,
    cs.cs_ship_cdemo_sk,
    cs.cs_ship_hdemo_sk,
    cs.cs_ship_addr_sk,
    cs.cs_call_center_sk,
    cs.cs_catalog_page_sk,
    cs.cs_ship_mode_sk,
    cs.cs_warehouse_sk,
    cs.cs_item_sk,
    cs.cs_promo_sk,
    cs.cs_order_number,
    cs.cs_quantity,
    cs.cs_wholesale_cost,
    cs.cs_list_price,
    cs.cs_sales_price,
    cs.cs_ext_discount_amt,
    cs.cs_ext_sales_price,
    cs.cs_ext_wholesale_cost,
    cs.cs_ext_list_price,
    cs.cs_ext_tax,
    cs.cs_coupon_amt,
    cs.cs_ext_ship_cost,
    cs.cs_net_paid,
    cs.cs_net_paid_inc_tax,
    cs.cs_net_paid_inc_ship,
    cs.cs_net_paid_inc_ship_tax,
    cs.cs_net_profit,
    cs.cs_sold_date_sk,
    case when cs.cs_sold_date_sk is not null then cs.cs_sold_date_sk else cast(rand() * 500 as int) end as distribute_key
  from ${SOURCE}.catalog_sales cs
  distribute by distribute_key
) tmp
;
