set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: store_sales                                      
-- ============================================================
drop table if exists store_sales;
create table store_sales
(
    ss_sold_date_sk           bigint,
    ss_sold_time_sk           bigint,
    ss_item_sk                bigint            not null,
    ss_customer_sk            bigint,
    ss_cdemo_sk               bigint,
    ss_hdemo_sk               bigint,
    ss_addr_sk                bigint,
    ss_store_sk               bigint,
    ss_promo_sk               bigint,
    ss_ticket_number          bigint            not null,
    ss_quantity               int,
    ss_wholesale_cost         decimal(7,2),
    ss_list_price             decimal(7,2),
    ss_sales_price            decimal(7,2),
    ss_ext_discount_amt       decimal(7,2),
    ss_ext_sales_price        decimal(7,2),
    ss_ext_wholesale_cost     decimal(7,2),
    ss_ext_list_price         decimal(7,2),
    ss_ext_tax                decimal(7,2),
    ss_coupon_amt             decimal(7,2),
    ss_net_paid               decimal(7,2),
    ss_net_paid_inc_tax       decimal(7,2),
    ss_net_profit             decimal(7,2)
)
using parquet
partitioned by (ss_sold_date_sk)
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true");

insert overwrite table store_sales partition (ss_sold_date_sk)
select
  tmp.ss_sold_time_sk,
  tmp.ss_item_sk,
  tmp.ss_customer_sk,
  tmp.ss_cdemo_sk,
  tmp.ss_hdemo_sk,
  tmp.ss_addr_sk,
  tmp.ss_store_sk,
  tmp.ss_promo_sk,
  tmp.ss_ticket_number,
  tmp.ss_quantity,
  tmp.ss_wholesale_cost,
  tmp.ss_list_price,
  tmp.ss_sales_price,
  tmp.ss_ext_discount_amt,
  tmp.ss_ext_sales_price,
  tmp.ss_ext_wholesale_cost,
  tmp.ss_ext_list_price,
  tmp.ss_ext_tax,
  tmp.ss_coupon_amt,
  tmp.ss_net_paid,
  tmp.ss_net_paid_inc_tax,
  tmp.ss_net_profit,
  tmp.ss_sold_date_sk
from(
  select
    ss.ss_sold_time_sk,
    ss.ss_item_sk,
    ss.ss_customer_sk,
    ss.ss_cdemo_sk,
    ss.ss_hdemo_sk,
    ss.ss_addr_sk,
    ss.ss_store_sk,
    ss.ss_promo_sk,
    ss.ss_ticket_number,
    ss.ss_quantity,
    ss.ss_wholesale_cost,
    ss.ss_list_price,
    ss.ss_sales_price,
    ss.ss_ext_discount_amt,
    ss.ss_ext_sales_price,
    ss.ss_ext_wholesale_cost,
    ss.ss_ext_list_price,
    ss.ss_ext_tax,
    ss.ss_coupon_amt,
    ss.ss_net_paid,
    ss.ss_net_paid_inc_tax,
    ss.ss_net_profit,
    ss.ss_sold_date_sk,
    case when ss.ss_sold_date_sk is not null then ss.ss_sold_date_sk else cast(rand() * 500 as int) end as distribute_key
  from ${SOURCE}.store_sales ss
  distribute by distribute_key
) tmp
;
