set spark.scheduler.session.priority=true;

create database if not exists ${DB};
use ${DB};

-- ============================================================
--   Table: web_returns                                      
-- ============================================================
drop table if exists web_returns;
create table web_returns
(
    wr_returned_date_sk       bigint,
    wr_returned_time_sk       bigint,
    wr_item_sk                bigint            not null,
    wr_refunded_customer_sk   bigint,
    wr_refunded_cdemo_sk      bigint,
    wr_refunded_hdemo_sk      bigint,
    wr_refunded_addr_sk       bigint,
    wr_returning_customer_sk  bigint,
    wr_returning_cdemo_sk     bigint,
    wr_returning_hdemo_sk     bigint,
    wr_returning_addr_sk      bigint,
    wr_web_page_sk            bigint,
    wr_reason_sk              bigint,
    wr_order_number           bigint            not null,
    wr_return_quantity        int,
    wr_return_amt             decimal(7,2),
    wr_return_tax             decimal(7,2),
    wr_return_amt_inc_tax     decimal(7,2),
    wr_fee                    decimal(7,2),
    wr_return_ship_cost       decimal(7,2),
    wr_refunded_cash          decimal(7,2),
    wr_reversed_charge        decimal(7,2),
    wr_account_credit         decimal(7,2),
    wr_net_loss               decimal(7,2)
)
using parquet
partitioned by (wr_returned_date_sk)
TBLPROPERTIES("parquet.compression"="SNAPPY","transactional"="true");

insert overwrite table web_returns partition (wr_returned_date_sk)

select
  tmp.wr_returned_time_sk,
  tmp.wr_item_sk,
  tmp.wr_refunded_customer_sk,
  tmp.wr_refunded_cdemo_sk,
  tmp.wr_refunded_hdemo_sk,
  tmp.wr_refunded_addr_sk,
  tmp.wr_returning_customer_sk,
  tmp.wr_returning_cdemo_sk,
  tmp.wr_returning_hdemo_sk,
  tmp.wr_returning_addr_sk,
  tmp.wr_web_page_sk,
  tmp.wr_reason_sk,
  tmp.wr_order_number,
  tmp.wr_return_quantity,
  tmp.wr_return_amt,
  tmp.wr_return_tax,
  tmp.wr_return_amt_inc_tax,
  tmp.wr_fee,
  tmp.wr_return_ship_cost,
  tmp.wr_refunded_cash,
  tmp.wr_reversed_charge,
  tmp.wr_account_credit,
  tmp.wr_net_loss,
  tmp.wr_returned_date_sk
from(
  select
    wr.wr_returned_time_sk,
    wr.wr_item_sk,
    wr.wr_refunded_customer_sk,
    wr.wr_refunded_cdemo_sk,
    wr.wr_refunded_hdemo_sk,
    wr.wr_refunded_addr_sk,
    wr.wr_returning_customer_sk,
    wr.wr_returning_cdemo_sk,
    wr.wr_returning_hdemo_sk,
    wr.wr_returning_addr_sk,
    wr.wr_web_page_sk,
    wr.wr_reason_sk,
    wr.wr_order_number,
    wr.wr_return_quantity,
    wr.wr_return_amt,
    wr.wr_return_tax,
    wr.wr_return_amt_inc_tax,
    wr.wr_fee,
    wr.wr_return_ship_cost,
    wr.wr_refunded_cash,
    wr.wr_reversed_charge,
    wr.wr_account_credit,
    wr.wr_net_loss,
    wr.wr_returned_date_sk,
    case when wr.wr_returned_date_sk is not null then wr.wr_returned_date_sk else cast(rand() * 500 as int) end as distribute_key
  from ${SOURCE}.web_returns wr
  distribute by distribute_key
) tmp;
