#!/usr/bin/env bash

set -e

source ./config
MT_VERIF_LOG_DIR=${LOG_DIR}/mt_verify

if [[ ! -d ${MT_VERIF_LOG_DIR} ]]; then
  mkdir -p ${MT_VERIF_LOG_DIR}/sqls
fi

THIS_LOG=${MT_VERIF_LOG_DIR}/run_verify_mt.log
> $THIS_LOG

# Use the ${ROUND} refresh data to do the verifying.
ROUND=$1

if [[ ! -d "./build/mtsqls_${ROUND}/" ]]; then
  log error "This script should be run after maitenaince test"
  exit 1
fi

cp -f mtsqls/*.sql ${MT_VERIF_LOG_DIR}/sqls
cp ./build/mtsqls_${ROUND}/*.sql ${MT_VERIF_LOG_DIR}/sqls

LF_FUNCS="LF_CR LF_CS LF_SR LF_SS LF_WR LF_WS LF_I"
DF_FUNCS="DF_CS DF_SS DF_WS DF_I"

for FUNC in `echo "$LF_FUNCS $DF_FUNCS" | xargs`; do
  > ${MT_VERIF_LOG_DIR}/verify_${FUNC}_$ROUND.out
done

VARS=""

function initVars() {
  LF=$1
  unset VARS
  unset TMP_VARS
  row_num=$2
  # turn off set -e because head may break the flow.
  set +e
  if [[ $row_num == "1" ]]; then
    # for the first row
    TMP_VARS=(`sed -n '/^| [0-9].*/p' logs/mt_verify/verify_${LF}_$ROUND.out | head -n 1 | xargs -d '|' | xargs`)
  else
    # for the second row
    TMP_VARS=(`sed -n '/^| [0-9].*/p' logs/mt_verify/verify_${LF}_$ROUND.out | head -n 2 | tail -n 1 | xargs -d '|' | xargs`)
  fi
  set -e
  case $LF in
    "LF_CR")
      for ii in `seq 0 15`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR9_/${VARS[9]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR10_/${VARS[10]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR11_/${VARS[11]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR12_/${VARS[12]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR13_/${VARS[13]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR14_/${VARS[14]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR15_/${VARS[15]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_CS")
      for ii in `seq 0 16`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR9_/${VARS[9]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR10_/${VARS[10]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR11_/${VARS[11]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR12_/${VARS[12]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR13_/${VARS[13]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR14_/${VARS[14]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR15_/${VARS[15]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR16_/${VARS[16]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_SR")
      for ii in `seq 0 8`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_SS")
      for ii in `seq 0 8`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_WR")
      for ii in `seq 0 12`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR9_/${VARS[9]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR10_/${VARS[10]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR11_/${VARS[11]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR12_/${VARS[12]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_WS")
      for ii in `seq 0 16`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR3_/${VARS[3]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR4_/${VARS[4]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR5_/${VARS[5]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR6_/${VARS[6]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR7_/${VARS[7]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR8_/${VARS[8]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR9_/${VARS[9]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR10_/${VARS[10]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR11_/${VARS[11]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR12_/${VARS[12]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR13_/${VARS[13]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR14_/${VARS[14]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR15_/${VARS[15]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR16_/${VARS[16]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
    "LF_I")
      for ii in `seq 0 2`; do
        if [[ ${TMP_VARS[$ii]} != "NULL" ]]; then
          VARS[$ii]="= ${TMP_VARS[$ii]}"
        else
          VARS[$ii]=" is null"
        fi
      done
      sed -i "s/_VAR0_/${VARS[0]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR1_/${VARS[1]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
      sed -i "s/_VAR2_/${VARS[2]}/g" ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql
    ;;
  esac
}

# step 1: execute delete functions (DF_XX.sql)
log info "Execute delete."
# Update CS and CR
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/DF_CS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update I
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/DF_I.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update SR and SS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/DF_SS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update WR and WS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/DF_WS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

wait

# step 2: ensure the deleted rows can not be fetched from target tables.
for DF in $DF_FUNCS; do
  log info "Verify the data deleted by $DF row cannot be selected."
  echo "====================================================" >> ${MT_VERIF_LOG_DIR}/verify_${DF}_$ROUND.out 2>&1
  echo "The rows deleted from target table should be empty:"  >> ${MT_VERIF_LOG_DIR}/verify_${DF}_$ROUND.out 2>&1
  echo "====================================================" >> ${MT_VERIF_LOG_DIR}/verify_${DF}_$ROUND.out 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/verify_$DF.sql >> ${MT_VERIF_LOG_DIR}/verify_${DF}_$ROUND.out 2>&1
done

# step 3: execute insert functions (LF_XX.sql).
log info "Execute insert."
# Update CS and CR
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_CR.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_CS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update I
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_I.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update SR and SS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_SR.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_SS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

# Update WR and WS
{
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_WR.sql --hivevar ROUND=${ROUND}  >> ${THIS_LOG} 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/LF_WS.sql --hivevar ROUND=${ROUND} >> ${THIS_LOG} 2>&1
}&

wait

# step 4: choose 2 rows randomly from temp view.
for LF in $LF_FUNCS; do
  log info "Choose two rows randomly from the view that to be inserted by $LF"
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "Two rows that need to be checked: "         >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/fetch_$LF.sql >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
done

# step 5: check the random rows fetched in step 1 are inserted to the target table.
for LF in $LF_FUNCS; do
  cp -f mtsqls/*_$LF.sql ${MT_VERIF_LOG_DIR}/sqls
  log info "Verify the first row inserted be $LF can be selected."
  initVars $LF 1
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "The first row returned from target table:"  >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1

  log info "Verify the second row inserted be $LF can be selected."
  cp -f mtsqls/*_$LF.sql ${MT_VERIF_LOG_DIR}/sqls
  initVars $LF 2
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "The second row returned from target table:" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  echo "==========================================" >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
  beeline --showStartEndTime=true -u jdbc:hive2://localhost:${PORT}/${DB} -f ${MT_VERIF_LOG_DIR}/sqls/verify_$LF.sql >> ${MT_VERIF_LOG_DIR}/verify_${LF}_$ROUND.out 2>&1
done
