#!/bin/bash

source config

LOG=${LOG_DIR}/data_access_test.log
> $LOG #clear the log

disk_host="emr-worker-3"
oss_host="emr-worker-8"
oss_endpoint="chenshi-i1-emr-tpcds-report.oss-cn-shenzhen-internal.aliyuncs.com"

log info "Data Accessibility Test Started." | tee -a $LOG 2>&1

if [ $STORE = 'hdfs' ]; then
  dir=hdfs
else
  dir=jboot
fi
log info "Collect ${disk_host} disk1 status before failure" > ${LOG_DIR}/Disk_Status_Good.out
pdsh -w $disk_host "sudo ls -l /mnt/disk1 | grep $dir " >> ${LOG_DIR}/Disk_Status_Good.out

log info "Move data directory to simulate disk failure" | tee -a $LOG 2>&1
# disable data directory
pdsh -w $disk_host "sudo mv /mnt/disk1/$dir /mnt/disk1/${dir}.bk"

log info "Collect ${disk_host} disk1 status after failure" > ${LOG_DIR}/Disk_Status_Fail.out
pdsh -w $disk_host "sudo ls -l /mnt/disk1 | grep $dir " >> ${LOG_DIR}/Disk_Status_Fail.out

if ! which mdadm > /dev/null 2>&1 ; then exit; fi

log info "Collect Master RAID1 status before failure" > ${LOG_DIR}/Raid_Status_Good.out
sudo mdadm -D /dev/md0 >> ${LOG_DIR}/Raid_Status_Good.out

log info "Remove vdd to simulate disk failure of RAID1" | tee -a $LOG 2>&1
# execute on master node
sudo mdadm --manage /dev/md0 --fail /dev/vdd >/dev/null 2>&1
sudo mdadm --manage /dev/md0 --remove /dev/vdd >/dev/null 2>&1

log info "Collect Master RAID1 status after failure" > ${LOG_DIR}/Raid_Status_Fail.out
sudo mdadm -D /dev/md0 >> ${LOG_DIR}/Raid_Status_Fail.out

if [ $STORE = 'hdfs' ]; then exit; fi

log info "Collect ${oss_host} oss accessbility before failure" > ${LOG_DIR}/Oss_Status_Good.out
pdsh -w $oss_host "ping -c 3 $oss_endpoint " >> ${LOG_DIR}/Oss_Status_Good.out

log info "Map oss endpoint to local host to simulate oss failure" | tee -a $LOG 2>&1
#disable oss
pdsh -w $oss_host sudo sed '\$a127.0.0.1\ '$oss_endpoint -i /etc/hosts

log info "Collect ${oss_host} oss accessbility after failure" > ${LOG_DIR}/Oss_Status_Fail.out
pdsh -w $oss_host "ping -c 3 $oss_endpoint " >> ${LOG_DIR}/Oss_Status_Fail.out
